@@ -344,11 +344,20 @@ class FileSystem(object):
         if not Path(document).exists():
             return
         meta = FileSystem.load_yaml(document)
-        click.secho('merge: {0}'.format(document.name), fg='blue')
-        for identifier, data in meta.items():
-            symbol = system.lookup(identifier)
-            if symbol:
-                merge(symbol.tags, data)
+        if not meta:
+            click.secho('skipping empty: {0}'.format(document.name), fg='blue')
+            return
+        else:
+            click.secho('merge: {0}'.format(document.name), fg='blue')
+        try:
+            for identifier, data in meta.items():
+                symbol = system.lookup(identifier)
+                if symbol:
+                    merge(symbol.tags, data)
+        except Exception as e:
+            click.secho('Error parsing annotation {0}: {1}'.format(document, e), fg='red', err=True)
+            if FileSystem.strict:
+                sys.exit(-1)
 
     @staticmethod
     def parse(input, identifier: str = None, use_cache=False, clear_cache=True, pattern="*.qface", profile=EProfile.FULL):
@@ -391,6 +400,8 @@ class FileSystem(object):
         if not document.exists():
             if required:
                 click.secho('yaml document does not exists: {0}'.format(document), fg='red', err=True)
+                if FileSystem.strict:
+                    sys.exit(-1)
             return {}
         try:
             return yaml.load(document.text(), Loader=Loader)
@@ -399,4 +410,6 @@ class FileSystem(object):
             if hasattr(exc, 'problem_mark'):
                 error = '{0}:{1}'.format(error, exc.problem_mark.line+1)
             click.secho('{0}: error: {1}'.format(error, str(exc)), fg='red', err=True)
+            if FileSystem.strict:
+                sys.exit(-1)
         return {}
